pub struct Config {
pub urls: HashMap<String, UrlEntry>,
pub groups: HashMap<String, Vec<String>>,
}Fields
urls: HashMap<String, UrlEntry>groups: HashMap<String, Vec<String>>Implementations
Sourceimpl Config
impl Config
Sourcepub fn resolve(&self, name: &str) -> Option<&str>
pub fn resolve(&self, name: &str) -> Option<&str>
Resolve a name (url name or alias) to a URL string.
pub fn validate(&self) -> Vec<String>
Sourcepub fn rename_url(&mut self, old: &str, new: &str) -> Result<(), Error>
pub fn rename_url(&mut self, old: &str, new: &str) -> Result<(), Error>
Rename a url key and cascade to group entries that reference it by name.
Sourcepub fn rename_alias(&mut self, old: &str, new: &str) -> Result<(), Error>
pub fn rename_alias(&mut self, old: &str, new: &str) -> Result<(), Error>
Rename an alias and cascade to group entries.
Sourcepub fn delete_url(&mut self, name: &str) -> Result<(), Error>
pub fn delete_url(&mut self, name: &str) -> Result<(), Error>
Delete a url and clean up group references to it and its aliases.