Config

Struct Config 

pub struct Config {
    pub urls: HashMap<String, UrlEntry>,
    pub groups: HashMap<String, Vec<String>>,
}

Fields

urls: HashMap<String, UrlEntry>groups: HashMap<String, Vec<String>>

Implementations

Source

impl Config

pub fn resolve(&self, name: &str) -> Option<&str>

Resolve a name (url name or alias) to a URL string.

pub fn contains(&self, name: &str) -> bool

Check if a name is a known url name or alias.

pub fn validate(&self) -> Vec<String>

pub fn rename_url(&mut self, old: &str, new: &str) -> Result<(), Error>

Rename a url key and cascade to group entries that reference it by name.

pub fn rename_alias(&mut self, old: &str, new: &str) -> Result<(), Error>

Rename an alias and cascade to group entries.

pub fn delete_url(&mut self, name: &str) -> Result<(), Error>

Delete a url and clean up group references to it and its aliases.

pub fn delete_alias(&mut self, alias: &str) -> Result<(), Error>

Delete an alias from its parent url and clean up group references.

pub fn rename_group(&mut self, old: &str, new: &str) -> Result<(), Error>

Rename a group key.

pub fn delete_group(&mut self, name: &str) -> Result<(), Error>

Delete a group.